from ._flight import FlightDescription, FlightSegment, Report

# 构造 Flight 1002
FLT1002 = FlightDescription(
    flight_number="1002",
    date="20-Jun-2020",
    doy="172/366",
    compensations=["2 (start & end)"],  # 补偿动作的描述
    survey_lines=[
        "10 repeat survey lines (5 Eastern Ontario & 5 Renfrew)",
        "Eastern Ontario & Renfrew free-fly on drape",
        "Renfrew free-fly at 555m",
    ],  # 巡查线描述
    issues=[
        Report("Missing Flux A data due to technical issue with instrument"),
        Report(
            "Mag 2 periodically dropped signal at ~180 degree headings during pitch/roll maneuvers",
            affected_lines=["1002.02", "1369.00", "1002.20"],
        ),
    ],
)

# 该航班的段落数据
segments_data_1002 = [
    (45100.00, 46370.00, "1002.01", "Transit to Compensation 1"),
    (46370.00, 47600.00, "1002.02", "Compensation 1"),
    (47600.00, 49310.00, "1002.03", "Transit to Renfrew repeat lines"),
    (49310.00, 49838.10, "158.00", "Renfrew repeat line"),
    (49838.10, 50051.90, "1002.04", "Renfrew turn"),
    (50051.90, 50560.50, "160.00", "Renfrew repeat line"),
    (50560.50, 50903.80, "1002.05", "Renfrew turn"),
    (50903.80, 51444.40, "1367.00", "Renfrew repeat line"),
    (51444.40, 51773.50, "1002.06", "Renfrew turn"),
    (51773.50, 52294.90, "1368.00", "Renfrew repeat line"),
    (52294.90, 52515.20, "1002.07", "Renfrew turn"),
    (52515.20, 53079.20, "1369.00", "Renfrew repeat line"),
    (53079.20, 53550.80, "1002.08", "Transit to Eastern Ontario repeat lines"),
    (53550.80, 54099.40, "3084.00", "Eastern Ontario repeat line"),
    (54099.40, 54376.80, "1002.09", "Eastern Ontario turn"),
    (54376.80, 54910.60, "3085.00", "Eastern Ontario repeat line"),
    (54910.60, 55142.40, "1002.10", "Eastern Ontario turn"),
    (55142.40, 55691.00, "3086.00", "Eastern Ontario repeat line"),
    (55691.00, 56064.40, "1002.11", "Eastern Ontario turn"),
    (56064.40, 56597.50, "320.00", "!!!HOLD-OUT TESTING DATA!!!"),
    (56597.50, 56808.40, "1002.12", "!!!HOLD-OUT TESTING DATA!!!"),
    (56808.40, 57319.20, "322.00", "!!!HOLD-OUT TESTING DATA!!!"),
    (57319.20, 57489.00, "1002.13", "Transit to Eastern Ontario Free-Fly"),
    (57489.00, 59946.00, "1002.14", "Eastern Ontario Free-Fly on Drape"),
    (
        59946.00,
        60846.00,
        "1002.14",
        "!!!HOLD-OUT TESTING DATA!!!",
    ),  # Duplicate line number?
    (60846.00, 61360.00, "1002.15", "Transit to Renfrew Free-Fly"),
    (61360.00, 63035.00, "1002.16", "Renfrew Free-Fly on Drape"),
    (
        63035.00,
        63935.00,
        "1002.16",
        "!!!HOLD-OUT TESTING DATA!!!",
    ),  # Duplicate line number?
    (63935.00, 65812.00, "1002.17", "Renfrew Free-Fly at 555m"),
    (65812.00, 66310.00, "1002.18", "Climb to high altitude"),
    (66310.00, 66560.00, "1002.19", "Transit to Compensation 2"),
    (66560.00, 67850.00, "1002.20", "Compensation 2"),
    (67850.00, 68910.00, "1002.21", "Transit to base"),
]

for start_time, end_time, line_number, description in segments_data_1002:
    FLT1002.add_segment(FlightSegment(start_time, end_time, line_number, description))


for start_time, end_time, line_number, description in segments_data_1002:
    FLT1002.add_segment(FlightSegment(start_time, end_time, line_number, description))
